==> mupad-1.4.2.tgz: mupad/share/mmg/include/kernel/MAR_array.h <==
/*  LAST EDIT: Tue Nov  8 09:55:09 1994 by Holger Naundorf (snoo)  */
/* $Date: 1997/08/21 07:17:21 $  $Author: kg $  $Revision: 1.8 $ */

/**************************************************************************/
/* FILE:             MAR_array.h                                          */
/* Autor:            Andreas Kemper                                       */
/* Erstellt:         02/12/91                                             */
/* Letzte Aenderung: 09/07/93                                             */
/**************************************************************************/

#ifndef __MAR_array__
#define __MAR_array__


/* Macros zur Erstellung einer tempor"aren Feldes von 'dim'-long-Werten */

#define MUP_new_long_list(l, sp, dim)                                    \
	{ sp = MMMmalloc(MMMCglobal,MMM_TMP,sizeof(long)*dim, 0L);       \
	  l = MMMZ(&sp,long,MMMwrite);                                   \
	  MMMpoolinsert(&l); }


#define MUP_free_long_list(l, sp)                                        \
        { MMMpooldelete(&l);						 \
	  MMMfree(sp); }


/*** Prototypen ***********************************************************/

S_Pointer MAR_new_array        ( long            dim,
				 long           **l );
S_Pointer MAR_eval_index       ( S_Pointer	 array, 
				 S_Pointer	 args );
S_Pointer MAR_build_sub_matrix ( S_Pointer	 array, 
				 long		 pos  );
S_Pointer MAR_eval_array       ( S_Pointer	 s,
				 long		 prev_func,
				 long		 eval_type,
				 S_Pointer	 exec );
S_Pointer MAR_eval_assign_elems( S_Pointer       s,
                                 long            prev_func,
                                 long            eval_type,
                                 S_Pointer       exec );
void      MAR_build_empty_array( S_Pointer	 result );
void      MAR_insert_eqn       ( S_Pointer	 *array, 
				 S_Pointer	 eqn  );
S_Pointer MAR_replace_array    ( S_Pointer 	*array, 
				 S_Pointer	 args, 
				 S_Pointer	 value,
                                 MUPbool         inplace,
                                 long            offset );

S_Pointer MAR_read_array       ( S_Pointer	 array, 
				 S_Pointer	 args );
S_Pointer MAR_new_nil_list     ( long		 size );

S_Pointer MAR_get_status_info  ( S_Pointer	 t ); 

S_Pointer MAR_get_operands     ( S_Pointer       array,
				 long            start,
				 long            end );

MUPbool   MAR_get_name	       ( S_Pointer	 array,
				 S_Pointer	*name );
void      MAR_set_name	       ( S_Pointer	 array,
				 S_Pointer	 name );

void MAR_check_initial_list(S_Pointer *array, 
			    long      *info, 
			    S_Pointer  list);


void MAR_init_list (  S_Pointer  target,
		      long       *pos,
		      long       dim, 
		      long      *range, 
		      long       depth, 
		      S_Pointer  source);

void MAR_init_list_div(S_Pointer    target,         
		       S_Pointer    source,
		       long         blocknr,      
		       long        *blockrange,    
		       long        *blockindex,
		       long 	   *maxblock,
		       long        *lastblock,
		       long        *block, 
		       long        *subblock,  
	               long         dim, 
	               long        *range,
		       long        *div, 
	               long         depth);

inline void MAR_write_array    ( S_Pointer 	*array, 
				 S_Pointer	 args, 
				 S_Pointer	 value,
                                 MUPbool         inplace,
                                 long            offset )
{
    S_Pointer res;
    res = MAR_replace_array(array, args, value, inplace, offset);
    MMMfree(res);
}

#endif /* __MAR_array__ */

==> mupad-2.0.0.tgz: mupad/share/mmg/include/kernel/MAR_array.h <==
/*  LAST EDIT: Tue Nov  8 09:55:09 1994 by Holger Naundorf (snoo)  */
/* $Date: 2000/09/29 08:23:04 $  $Author: kg $  $Revision: 1.8 $ */

/**************************************************************************/
/* FILE:             MAR_array.h                                          */
/* Autor:            Andreas Kemper                                       */
/* Erstellt:         02/12/91                                             */
/* Letzte Aenderung: 09/07/93                                             */
/**************************************************************************/

#ifndef __MAR_array__
#define __MAR_array__


/* Prototypen ***********************************************************/

S_Pointer MAR_new_array        ( long            dim,
				 long           **l );
S_Pointer MAR_eval_index       ( S_Pointer	 array,
				 S_Pointer	 args );
S_Pointer MAR_eval_array       ( S_Pointer	 s,
				 long		 prev_func,
				 long		 eval_type,
				 S_Pointer	 exec );
S_Pointer MAR_eval_assign_elems( S_Pointer       s,
                                 long            prev_func,
                                 long            eval_type,
                                 S_Pointer       exec );
void      MAR_build_empty_array( S_Pointer	 result );
void      MAR_insert_eqn       ( S_Pointer	 *array,
				 S_Pointer	 eqn  );
S_Pointer MAR_replace_array    ( S_Pointer 	*array,
				 S_Pointer	 args,
				 S_Pointer	 value,
                                 bool            inplace,
                                 long            offset,
                                 long           *error);

S_Pointer MAR_read_array       ( S_Pointer	 array,
				 S_Pointer	 args );
S_Pointer MAR_new_nil_list     ( long		 size );

S_Pointer MAR_get_status_info  ( S_Pointer	 t );

S_Pointer MAR_get_operands     ( S_Pointer       array,
				 long            start,
				 long            end );

bool   MAR_get_name	       ( S_Pointer	 array,
				 S_Pointer	*name );
void      MAR_set_name	       ( S_Pointer	 array,
				 S_Pointer	 name );

void MAR_check_initial_list(S_Pointer *array,
			    long      *info,
			    S_Pointer  list);


void MAR_init_list (  S_Pointer  target,
		      long       *pos,
		      long       dim,
		      long      *range,
		      long       depth,
		      S_Pointer  source);


inline void MAR_write_array    ( S_Pointer 	*array,
				 S_Pointer	 args,
				 S_Pointer	 value,
                                 bool            inplace,
                                 long            offset,
                                 long           *error)
{
    S_Pointer res;
    res = MAR_replace_array(array, args, value, inplace, offset, error);
    MMMfree(res);
}

#endif /* __MAR_array__ */
